Welcome to razorback's documentation!
=====================================


Razorback is a python package for estimating transfer functions between time signals.
Its primary application field is magnetotelluric (MT) and other electromagnetic geophysical methods.


.. toctree::
   :maxdepth: 2
   :caption: User Guide

   install
   citation
   overview
   tutorials/index
   script


.. toctree::
   :maxdepth: 1
   :caption: Reference API

   api/razorback


* :ref:`genindex`

